@@ -12,6 +12,8 @@
 #include <X11/extensions/XShm.h>
 #endif
 
+#include <xine/xineutils.h>
+
 #ifdef __EMX__
 extern const char *__XOS2RedirRoot(const char *);
 #endif
@@ -85,7 +87,6 @@ Imlib_init(Display * disp)
   char               *palfile;
   int                 loadpal;
   int                 vis;
-  int                 newcm;
   char               *old_locale;
 
   /* fprintf(stderr, "Imlib Init\n");
@@ -527,7 +528,6 @@ Imlib_init(Display * disp)
     at.override_redirect = True;
     mask = CWOverrideRedirect | CWBackPixel | CWBorderPixel |
       CWBackingStore | CWSaveUnder;
-    newcm = 0;
     if (id->x.visual != DefaultVisual(disp, id->x.screen))
       {
 	Colormap            cm;
@@ -539,7 +539,6 @@ Imlib_init(Display * disp)
 	    mask |= CWColormap;
 	    id->x.root_cmap = cm;
 	    at.colormap = cm;
-	    newcm = 1;
 	  }
       }
     id->x.base_window = XCreateWindow(id->x.disp, id->x.root,
@@ -1151,10 +1150,9 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
   {
     /* Turn off fastrender if there is an endianess diff between */
     /* client and Xserver */
-    int                 byt, bit;
+    int                 byt;
 
     byt = ImageByteOrder(id->x.disp);	/* LSBFirst | MSBFirst */
-    bit = BitmapBitOrder(id->x.disp);	/* LSBFirst | MSBFirst */
     /* if little endian && server big */
     if ((htonl(1) != 1) && (byt == MSBFirst))
       id->fastrend = 0;
