@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2008 the xine project
+ * Copyright (C) 2000-2013 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -667,6 +667,9 @@ void gui_exit (xitk_widget_t *w, void *data) {
     }
     
     xine_stop (gGui->stream);
+    while(xine_get_status(gGui->stream) == XINE_STATUS_PLAY)
+      xine_usec_sleep(50000);
+
     gGui->ignore_next = 0;
   }
   
@@ -2145,7 +2148,8 @@ static void fileselector_callback(filebrowser_t *fb) {
 
     /* If an MRL is not being played, select the first file appended. If in "smart mode" start
        playing the entry.  If a an MRL is currently being played, let it continue normally */
-    if((first != gGui->playlist.num) && (xine_get_status(gGui->stream) == XINE_STATUS_STOP)) {
+    if((first != gGui->playlist.num) &&
+      (gGui->logo_mode || (xine_get_status(gGui->stream) == XINE_STATUS_STOP))) {
       gGui->playlist.cur = first;
       if(gGui->smart_mode) {
         gui_set_current_mmk(mediamark_get_current_mmk());
