@@ -1952,7 +1952,7 @@ static void on_start(void *data) {
     int dummy_session;
     
     while(startup->session_opts[i])
-      (void) session_handle_subopt(startup->session_opts[i++], &dummy_session);
+      (void) session_handle_subopt(startup->session_opts[i++], NULL, &dummy_session);
     
   }
   
