@@ -21,7 +21,7 @@
  *
  */
 /* required for getsubopt(); the __sun test gives us strncasecmp() on solaris */
-#if !defined(__sun) && ! defined(__FreeBSD__)
+#if !defined(__sun) && ! defined(__FreeBSD__) && ! defined(__NetBSD__) && ! defined(__DragonFly__)
 #define _XOPEN_SOURCE 500
 #endif
 /* required for strncasecmp() */
@@ -427,7 +427,7 @@ static void show_version(void) {
 #ifdef DEBUG
   printf("-[DEBUG]");
 #endif
-  printf(_(".\n(c) 2000-2010 The xine Team.\n"));
+  printf(_(".\n(c) 2000-2014 The xine Team.\n"));
 }
 
 /*
@@ -1255,8 +1255,10 @@ static void event_listener(void *user_data, const xine_event_t *event) {
       gGui->mixer.volume_level = (aevent->left + aevent->right) / 2;
       if(gGui->mixer.method == SOUND_CARD_MIXER) {
 	gGui->mixer.mute = aevent->mute;
-	xitk_slider_set_pos(panel->mixer.slider, gGui->mixer.volume_level);
-	xitk_checkbox_set_state(panel->mixer.mute, gGui->mixer.mute);
+	if (panel) {
+	  xitk_slider_set_pos(panel->mixer.slider, gGui->mixer.volume_level);
+	  xitk_checkbox_set_state(panel->mixer.mute, gGui->mixer.mute);
+	}
       }
     }
     break;
@@ -1783,7 +1785,7 @@ int main(int argc, char *argv[]) {
       
     case 'S':
       if(is_remote_running(((session >= 0) ? session : 0)))
-	retval = session_handle_subopt(optarg, &session);
+	retval = session_handle_subopt(optarg, NULL, &session);
       else {
 	
 	session_argv = (char **) realloc(session_argv, sizeof(char *) * (session_argv_num + 2));
@@ -1935,9 +1937,9 @@ int main(int argc, char *argv[]) {
       if(_argv[optind]) {
 	for(i = optind; i < _argc; i++) {
 	  char enqueue_mrl[strlen(_argv[i]) + 256];
-
-	  snprintf(enqueue_mrl, sizeof(enqueue_mrl), "session=%d,mrl=%s", session, atoa(_argv[i]));
-	  (void) session_handle_subopt(enqueue_mrl, &session);
+	  char *filename = NULL;
+	  snprintf(enqueue_mrl, sizeof(enqueue_mrl), "session=%d", session);
+	  (void) session_handle_subopt(enqueue_mrl, _argv[i], &session);
 	}
       }
       else
