@@ -24,7 +24,7 @@
 /* required for getsubopt(); the __sun test avoids compilation problems on 
     solaris. On FreeBSD defining this disable BSD functions to be visible
     and remove INADDR_NONE */
-#if ! defined (__sun__) && ! defined (__OpenBSD__)  && ! defined(__FreeBSD__) && ! defined(__APPLE__)
+#if ! defined (__sun__) && ! defined (__OpenBSD__)  && ! defined(__FreeBSD__) && ! defined(__NetBSD__) && ! defined(__APPLE__) && ! defined (__DragonFly__)
 #define _XOPEN_SOURCE 500
 #endif
 /* required for strncasecmp() */
@@ -294,7 +294,7 @@ static commands_t commands[] = {
     "  playlist next\n"
     "  playlist last\n"
     "  playlist stop\n"
-    "  playlist contine"
+    "  playlist continue"
   },
   { "stop",        NO_ARGS,         PUBLIC,          NEED_AUTH,     do_stop,
     "stop playback", 
@@ -458,7 +458,7 @@ static int sock_create(const char *service, const char *transport, struct sockad
   if(!sin->sin_port) {
     iservice = getservbyname(service, "tcp");
 
-    if(!service)
+    if(!iservice)
       sock_err("Service not registered: %s\n", service);
     
     sin->sin_port = iservice->s_port;
@@ -1255,7 +1255,7 @@ int main(int argc, char **argv) {
   rl_readline_name = PROGNAME;
   rl_set_prompt(session.prompt);
   rl_initialize();
-  rl_attempted_completion_function = (CPPFunction *)completion_function;
+  rl_attempted_completion_function = completion_function;
   
   signal(SIGPIPE, SIG_IGN);
   
@@ -1294,6 +1294,9 @@ int main(int argc, char **argv) {
     session_update_prompt(&session);
 
     if((grabbed_line = readline(session.prompt)) == NULL) {
+      if (errno == 0 || errno == ENOTTY)
+        exit(0);
+
       fprintf(stderr, "%s(%d): readline() failed: %s\n",
 	      __XINE_FUNCTION__, __LINE__, strerror(errno));
       exit(1);
@@ -2701,7 +2704,7 @@ static void parse_command(client_info_t *client_info) {
   
   if(client_info->command.num_args) {
     for(i = 0; i < client_info->command.num_args; i++)
-      memset(client_info->command.args[i], 0, sizeof(client_info->command.args[i]));
+      *client_info->command.args[i] = 0;
   }
   
   client_info->command.num_args = 0;
@@ -2716,7 +2719,7 @@ static void parse_command(client_info_t *client_info) {
     client_info->command.command = (char *) realloc(client_info->command.command, 
 						    strlen(client_info->command.line) - strlen(cmd) + 1);
 
-    memset(client_info->command.command, 0, sizeof(client_info->command.command));
+    *client_info->command.command = 0;
     strlcpy(client_info->command.command, client_info->command.line,
 	    (strlen(client_info->command.line) - strlen(cmd)));
 
@@ -2864,8 +2867,14 @@ static __attribute__((noreturn)) void *client_thread(void *data) {
   char               buffer[_BUFSIZ];
   int                i;
   int                len;
+  sigset_t           sigpipe_mask;
   
   pthread_detach(pthread_self());
+
+  sigemptyset(&sigpipe_mask);
+  sigaddset(&sigpipe_mask, SIGPIPE);
+  if (pthread_sigmask(SIG_BLOCK, &sigpipe_mask, NULL) == -1)
+    perror("pthread_sigmask");
   
   client_info->finished = 0;
   memset(&client_info->name, 0, sizeof(client_info->name));
