@@ -21,7 +21,7 @@
 /* Largely inspired of xmms control socket stuff */
 
 /* required for getsubopt(); the __sun test gives us strncasecmp() on solaris */
-#if ! defined (__sun) && ! defined (__OpenBSD__) && ! defined (__FreeBSD__)
+#if ! defined (__sun) && ! defined (__OpenBSD__) && ! defined (__FreeBSD__) && !defined(__NetBSD__) && !defined(__DragonFly__)
 #define _XOPEN_SOURCE 500
 #endif
 
@@ -499,7 +499,7 @@ static int sanestrcasecmp(char *s1, char *s2) {
   return 1;
 } 
 
-int session_handle_subopt(char *suboptarg, int *session) {
+int session_handle_subopt(char *suboptarg, char *enqueue_mrl, int *session) {
   int          playlist_first, playlist_last, playlist_clear, playlist_next, playlist_prev, playlist_stop_cont;
   int          audio_next, audio_prev, spu_next, spu_prev;
   int          volume, amp, loop, speed_status, time_status;
@@ -634,6 +634,12 @@ int session_handle_subopt(char *suboptarg, int *session) {
 
     }
   }
+
+  if (enqueue_mrl != NULL) {
+    mrls = (char **) realloc(mrls, sizeof(char *) * (num_mrls + 2));
+    mrls[num_mrls++] = strdup(enqueue_mrl);
+    mrls[num_mrls]   = NULL;
+  }
   
   *session = (optsess >= 0) ? optsess : 0;
   
