@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2008 the xine project
+ * Copyright (C) 2000-2013 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -337,14 +337,16 @@ int xitk_uninstall_x_error_handler(void) {
 static void xitk_signal_handler(int sig) {
   pid_t cur_pid = getppid();
 
-  /* First, call registered handler */
-  if(cur_pid == xitk_pid) {
-    if(gXitk->sig_callback)
-      gXitk->sig_callback(sig, gXitk->sig_data);
+  if (gXitk) {
+    /* First, call registered handler */
+    if(cur_pid == xitk_pid) {
+      if(gXitk->sig_callback)
+        gXitk->sig_callback(sig, gXitk->sig_data);
+    }
+  
+    gXitk->running = 0;
   }
-  
-  gXitk->running = 0;
-  
+
   switch (sig) {
     
   case SIGINT:
@@ -352,11 +354,13 @@ static void xitk_signal_handler(int sig) {
   case SIGQUIT:
     if(cur_pid == xitk_pid) {
       
-      xitk_list_free(gXitk->list);
-      xitk_list_free(gXitk->gfx);
-      xitk_config_deinit(gXitk->config);
+      if (gXitk) {
+        xitk_list_free(gXitk->list);
+        xitk_list_free(gXitk->gfx);
+        xitk_config_deinit(gXitk->config);
       
-      XITK_FREE(gXitk);
+        XITK_FREE(gXitk);
+      }
       exit(1);
     }
     break;
@@ -2112,6 +2116,9 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
     tv.tv_usec = 33000;
 
     select(xconnection + 1, &r, 0, 0, &tv);
+
+    if(!gXitk->running)
+      break;
     
     XLOCK(gXitk->display);
     got_event = (XPending(gXitk->display) != 0);
@@ -2123,6 +2130,9 @@ void xitk_run(xitk_startup_callback_t cb, void *data) {
 
       xitk_xevent_notify(&myevent);
 
+      if(!gXitk->running)
+        break;
+
       XLOCK(gXitk->display);
       got_event = (XPending(gXitk->display) != 0);
       if( got_event )
